@@ -51,14 +51,12 @@ package com.openexchange.admin.autocontextid.storage.mysqlStorage;
 
 import java.sql.Connection;
 import java.sql.SQLException;
-import org.apache.commons.logging.Log;
 import com.openexchange.admin.autocontextid.daemons.ClientAdminThreadExtended;
 import com.openexchange.admin.autocontextid.storage.sqlStorage.OXAutoCIDSQLStorage;
 import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.groupware.impl.IDGenerator;
-import com.openexchange.log.LogFactory;
 
 /**
  * @author choeger
@@ -67,7 +65,7 @@ public final class OXAutoCIDMySQLStorage extends OXAutoCIDSQLStorage {
 
     private static AdminCache cache = null;
 
-    private static final Log log = LogFactory.getLog(OXAutoCIDMySQLStorage.class);
+    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(OXAutoCIDMySQLStorage.class);
 
     static {
         cache = ClientAdminThreadExtended.cache;
@@ -83,7 +81,7 @@ public final class OXAutoCIDMySQLStorage extends OXAutoCIDSQLStorage {
         try {
             con = cache.getConnectionForConfigDB();
         } catch (final PoolException e) {
-            log.error(e.getMessage(), e);
+            log.error("", e);
             throw new StorageException(e.getMessage());
         }
         boolean rollback = false;
